function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var d3Shape = require('d3-shape');
var bar = require('@nivo/bar');
var html2canvas = _interopDefault(require('html2canvas'));
var fileSaver = require('file-saver');

var styles = {"mainDiv":"_2zQN5","Appy":"_2C6sr","graphWrapper":"_3N3WD","wrapper":"_1I_qj","labelLeft":"_AECL5","labelRight":"_2408r","legendWrapper":"_1cNhw","legendItems":"_14lMM","legendItem":"_ShEp8","legendColor":"_1155L","graphContainer":"_2EyYF","secondGraph":"_1h3iW","tooltip":"_LfsGP"};

function Tooltip(props) {
  var data = props.data;
  console.log(data);
  return /*#__PURE__*/React__default.createElement("div", {
    className: styles.tooltip
  }, /*#__PURE__*/React__default.createElement("p", null, "Month: ", data.x), /*#__PURE__*/React__default.createElement("p", null, "Revenue: ", data.v, "k"), /*#__PURE__*/React__default.createElement("p", null, "Revenue Change %: ", data.v1, "%"));
}

var barColor = '#4696EC';
var lineColor = '#000000';

function App(_ref) {
  var data = _ref.data,
      legendData = _ref.legendData,
      height = _ref.height,
      width = _ref.width;
  var heightStyle = {
    height: height,
    width: width
  };

  var Line = function Line(_ref2) {
    var bars = _ref2.bars,
        xScale = _ref2.xScale,
        yScale = _ref2.yScale;
    var lineGenerator = d3Shape.line().x(function (bar) {
      return xScale(bar.data.data.x) + bar.width / 2;
    }).y(function (bar) {
      return yScale(bar.data.data.v1);
    });
    return /*#__PURE__*/React__default.createElement(React.Fragment, null, /*#__PURE__*/React__default.createElement("path", {
      d: lineGenerator(bars),
      fill: "none",
      stroke: lineColor,
      strokeWidth: "3",
      style: {
        pointerEvents: 'none'
      }
    }), bars.map(function (bar) {
      return /*#__PURE__*/React__default.createElement("circle", {
        key: bar.key,
        cx: xScale(bar.data.data.x) + bar.width / 2,
        cy: yScale(bar.data.data.v1),
        r: 4,
        fill: "white",
        stroke: lineColor,
        style: {
          pointerEvents: 'none'
        }
      });
    }));
  };

  var FirstGraph = function FirstGraph() {
    return /*#__PURE__*/React__default.createElement(bar.ResponsiveBar, {
      groupMode: "grouped",
      layout: "vertical",
      data: data,
      keys: ['v', 'v1', 'v2'],
      padding: 0.4,
      margin: {
        top: 10,
        right: 10,
        bottom: 36,
        left: 36
      },
      axisLeft: {
        tickSize: 0
      },
      indexBy: "x",
      enableLabel: false,
      colors: [barColor, '#50DBB4', '#E03B8B'],
      borderRadius: 2,
      labelSkipWidth: 12,
      labelSkipHeight: 12,
      tooltip: function tooltip(props) {
        return /*#__PURE__*/React__default.createElement(Tooltip, {
          data: data[props.index]
        });
      },
      layers: ['grid', 'axes', 'bars', 'markers', 'legends']
    });
  };

  var SecondGraph = function SecondGraph() {
    return /*#__PURE__*/React__default.createElement(bar.ResponsiveBar, {
      groupMode: "grouped",
      layout: "vertical",
      data: data,
      keys: ['v1'],
      padding: 0.6,
      indexBy: "x",
      axisRight: {
        tickPadding: -20,
        tickSize: 0
      },
      margin: {
        top: 10,
        right: 12,
        bottom: 36,
        left: 36
      },
      axisLeft: null,
      enableLabel: false,
      colors: "#1C00ff00",
      borderRadius: 2,
      labelSkipWidth: 12,
      labelSkipHeight: 12,
      enableGridY: false,
      axisBottom: false,
      tooltip: function tooltip(props) {
        return /*#__PURE__*/React__default.createElement(Tooltip, {
          data: data[props.index]
        });
      },
      layers: ['grid', 'axes', 'bars', Line, 'markers', 'legends']
    });
  };

  return /*#__PURE__*/React__default.createElement("div", {
    className: styles.App
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.wrapper,
    style: heightStyle
  }, /*#__PURE__*/React__default.createElement("p", {
    className: styles.labelLeft
  }, "TR"), /*#__PURE__*/React__default.createElement("p", {
    className: styles.labelRight
  }, "TR Change"), /*#__PURE__*/React__default.createElement("div", {
    className: styles.graphWrapper
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.secondGraph,
    style: heightStyle
  }, /*#__PURE__*/React__default.createElement(SecondGraph, null)), /*#__PURE__*/React__default.createElement("div", {
    className: styles.graphContainer,
    style: heightStyle
  }, /*#__PURE__*/React__default.createElement(FirstGraph, null)))), /*#__PURE__*/React__default.createElement("div", {
    className: styles.legendWrapper
  }, /*#__PURE__*/React__default.createElement("div", {
    className: styles.legendItems
  }, legendData.map(function (item, index) {
    return /*#__PURE__*/React__default.createElement("div", {
      className: styles.legendItem,
      key: index
    }, /*#__PURE__*/React__default.createElement("span", {
      className: styles.legendColor,
      style: {
        backgroundColor: item.color
      }
    }), /*#__PURE__*/React__default.createElement("p", null, item.type));
  }))));
}

function ChartApp(_ref) {
  var data = _ref.data,
      legendData = _ref.legendData,
      height = _ref.height,
      width = _ref.width;
  var heightStyle = {
    height: height,
    width: width
  };
  var chartRef = React.useRef(null);

  var exportChart = function exportChart() {
    console.log(chartRef);
    html2canvas(chartRef.current, {
      scrollY: -window.scrollY
    }).then(function (canvas) {
      var base64image = canvas.toDataURL('image/png');
      fileSaver.saveAs(base64image, 'Monthly Revenue Chart.png');
    })["catch"](function (err) {
      console.log(err);
    });
  };

  return /*#__PURE__*/React__default.createElement("div", {
    className: styles.Appy,
    style: heightStyle
  }, /*#__PURE__*/React__default.createElement("div", {
    ref: chartRef
  }, /*#__PURE__*/React__default.createElement(App, {
    data: data,
    legendData: legendData,
    height: height,
    width: width
  })), /*#__PURE__*/React__default.createElement("button", {
    onClick: exportChart
  }, "Download"));
}

module.exports = ChartApp;
//# sourceMappingURL=index.js.map
